@@ -1,7 +1,7 @@
 package Template::Mustache::Token::Partial;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Object representing a Partial block
-$Template::Mustache::Token::Partial::VERSION = '1.2.0';
+$Template::Mustache::Token::Partial::VERSION = '1.3.0';
 use Moo;
 
 use MooseX::MungeHas { has_ro => [ 'is_ro' ], has_rw => [ 'is_rw' ] };
@@ -18,7 +18,7 @@ sub render {
         my $template = $partials->($self->name)
             or return '';
 
-        $partial = Template::Mustache->new( template => $template )->parsed;
+        $partial = ref $template ? $template : Template::Mustache->new( template => $template )->parsed;
     }
     else {
         $partial = $partials->{$self->name} or return '';
@@ -41,7 +41,7 @@ Template::Mustache::Token::Partial - Object representing a Partial block
 
 =head1 VERSION
 
-version 1.2.0
+version 1.3.0
 
 =head1 AUTHORS
 
@@ -63,7 +63,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2011 by Pieter van de Bruggen.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2011 by Pieter van de Bruggen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
